@@ -38,30 +38,28 @@
     Changelog is available at
     http://code.michael-noll.com/?p=deliciousapi;a=log
 
-    Copyright 2006-2009 Michael G. Noll <http://www.michael-noll.com/>
+    Copyright 2006-2010 Michael G. Noll <http://www.michael-noll.com/>
 
 """
 
 __author__ = "Michael G. Noll"
-__copyright__ = "(c) 2006-2009 Michael G. Noll"
+__copyright__ = "(c) 2006-2010 Michael G. Noll"
 __description__ = "Unofficial Python API for retrieving data from Delicious.com"
 __email__ = "coding[AT]michael-REMOVEME-noll[DOT]com"
 __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.15"
+__version__ = "1.6.7"
 
-import base64
 import cgi
 import datetime
-import md5
+import hashlib
 from operator import itemgetter
 import re
 import socket
 import time
 import urllib2
-import xml.dom.minidom
 
 try:
     from BeautifulSoup import BeautifulSoup
@@ -239,7 +237,8 @@ class DeliciousURL(object):
     tags = property(fget=get_tags, doc="Returns a dictionary mapping tags to their tag count")
 
     def get_hash(self):
-        m = md5.new(self.url)
+        m = hashlib.md5()
+        m.update(self.url)
         return m.hexdigest()
     hash = property(fget=get_hash, doc="Returns the MD5 hash of the URL of this document")
 
@@ -433,7 +432,8 @@ class DeliciousAPI(object):
 
         document = DeliciousURL(url)
 
-        m = md5.new(url)
+        m = hashlib.md5()
+        m.update(url)
         hash = m.hexdigest()
 
         path = "/v2/json/urlinfo/%s" % hash
@@ -670,7 +670,8 @@ class DeliciousAPI(object):
 
         path = None
         if url:
-            m = md5.new(url)
+            m = hashlib.md5()
+            m.update(url)
             hash = m.hexdigest()
 
             # path will change later on if there are multiple pages of boomarks
@@ -696,7 +697,7 @@ class DeliciousAPI(object):
                     bookmarks.extend(self._extract_bookmarks_from_user_history(data))
 
                 # stop scraping if we already have as many bookmarks as we want
-                if len(bookmarks) >= max_bookmarks:
+                if (len(bookmarks) >= max_bookmarks) and max_bookmarks != 0:
                     break
                 else:
                     # check if there are multiple pages of bookmarks for this
@@ -764,9 +765,9 @@ class DeliciousAPI(object):
             user_tags = []
             tagdisplays = bookmark_element.findAll("div", attrs={"class": "tagdisplay"})
             if tagdisplays:
-                spans = tagdisplays[0].findAll("span", attrs={"class": "tag-chain-item-span"})
-                for span in spans:
-                    tag = span.contents[0]
+                aset  = tagdisplays[0].findAll("a", attrs={"class": "tag noplay"})
+                for a in aset:
+                    tag = a.contents[0]
                     user_tags.append(tag)
 
             # extract user information
@@ -774,20 +775,17 @@ class DeliciousAPI(object):
             if metas:
                 links = metas[0].findAll("a", attrs={"class": "user user-tag"})
                 if links:
-                    user_a = links[0]
-                    spans = user_a.findAll('span')
-                    if spans:
-                        try:
-                            user = spans[0].contents[0]
-                        except IndexError:
-                            # WORKAROUND: it seems there is a bug on Delicious.com where
-                            # sometimes a bookmark is shown in a URL history without any
-                            # associated Delicious username (username is empty); this could
-                            # be caused by special characters in the username or other things
-                            #
-                            # this problem of Delicious is very rare, so we just skip such
-                            # entries until they find a fix
-                            pass
+                    try:
+                        user = links[0]['href'][1:]
+                    except IndexError:
+                        # WORKAROUND: it seems there is a bug on Delicious.com where
+                        # sometimes a bookmark is shown in a URL history without any
+                        # associated Delicious username (username is empty); this could
+                        # be caused by special characters in the username or other things
+                        #
+                        # this problem of Delicious is very rare, so we just skip such
+                        # entries until they find a fix
+                        pass
                     bookmarks.append( (user, user_tags, comment, timestamp) )
 
         return bookmarks
@@ -832,7 +830,7 @@ class DeliciousAPI(object):
                 datas = bookmark_element.findAll("div", attrs={"class": "data"})
                 if datas:
                     links = datas[0].findAll("a", attrs={"class": re.compile("^taggedlink\s*")})
-                    if links:
+                    if links and links[0].contents:
                         title = links[0].contents[0].strip()
                         url = links[0]['href']
                     divs = datas[0].findAll("div", attrs={"class": "description"})
@@ -843,9 +841,9 @@ class DeliciousAPI(object):
                 url_tags = []
                 tagdisplays = bookmark_element.findAll("div", attrs={"class": "tagdisplay"})
                 if tagdisplays:
-                    spans = tagdisplays[0].findAll("span", attrs={"class": "tag-chain-item-span"})
-                    for span in spans:
-                        tag = span.contents[0]
+                    aset = tagdisplays[0].findAll("a", attrs={"class": "tag noplay"})
+                    for a in aset:
+                        tag = a.contents[0]
                         url_tags.append(tag)
 
                 bookmarks.append( (url, url_tags, title, comment, timestamp) )
@@ -860,11 +858,10 @@ class DeliciousAPI(object):
         bookmark collection (which also includes private bookmarks) is
         retrieved. Data communication is encrypted using SSL in this case.
 
-        If no password is supplied, only the most recent public bookmarks
-        of the user are extracted from his/her JSON feed (up to 100 bookmarks
-        if any). Note that if you want to get the *full* tagging vocabulary
-        of the user even if you don't know the password, you can call
-        get_tags_of_user() instead.
+        If no password is supplied, only the *public* bookmarks of the user
+        are retrieved. Here, the parameter 'max_bookmarks' specifies how
+        many public bookmarks will be retrieved (default: 50). Set the
+        parameter to 0 to retrieve all public bookmarks.
 
         This function can be used to backup all of a user's bookmarks if
         called with a username and password.
@@ -881,6 +878,9 @@ class DeliciousAPI(object):
             See the documentation of get_bookmarks() for more
             information as get_url() uses get_bookmarks() to
             retrieve a url's bookmarking history.
+            The parameter is NOT used when a password is specified
+            because in this case the *full* bookmark collection of
+            a user will be retrieved.
         @type max_bookmarks: int
 
         @param sleep_seconds: Optional, default: 1.
